==> libfwbuilder_2.0.9.orig.tar.gz: libfwbuilder-2.0.9/src/fwbuilder/Interval.h <==
/* 

                          Firewall Builder

                 Copyright (C) 2000 NetCitadel, LLC

  Author:  Vadim Kurland     vadim@vk.crocodile.org

  $Id: Interval.h,v 1.2 2004/09/08 05:34:50 vkurland Exp $


  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/


#ifndef __INTERVAL_HH_FLAG__
#define __INTERVAL_HH_FLAG__

#include <fwbuilder/FWObject.h>

namespace libfwbuilder
{

class Interval : public FWObject 
{

public:

    Interval();
    Interval(const FWObject *root);
    
    void setStartTime(int min,int hour,int day,int month,int year,int dayofweek);
    void setEndTime(int min,int hour,int day,int month,int year,int dayofweek);

    void getStartTime(int *min,int *hour,int *day,int *month,int *year,int *dayofweek) const;
    void getEndTime(int *min,int *hour,int *day,int *month,int *year,int *dayofweek) const;

    virtual void fromXML(xmlNodePtr parent) throw(FWException);

    DECLARE_FWOBJECT_SUBTYPE(Interval);

    virtual FWReference* createRef();

    bool isAny();
};

}

#endif

==> libfwbuilder_2.1.19.orig.tar.gz: libfwbuilder-2.1.19/src/fwbuilder/Interval.h <==
/* 

                          Firewall Builder

                 Copyright (C) 2000 NetCitadel, LLC

  Author:  Vadim Kurland     vadim@vk.crocodile.org

  $Id: Interval.h,v 1.3 2006/09/10 22:40:37 vkurland Exp $


  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/


#ifndef __INTERVAL_HH_FLAG__
#define __INTERVAL_HH_FLAG__

#include <fwbuilder/FWObject.h>

namespace libfwbuilder
{

class Interval : public FWObject 
{

public:

    Interval();
    Interval(const FWObject *root,bool prepopulate);
    
    void setStartTime(int min,int hour,int day,int month,int year,int dayofweek);
    void setEndTime(int min,int hour,int day,int month,int year,int dayofweek);

    void getStartTime(int *min,int *hour,int *day,int *month,int *year,int *dayofweek) const;
    void getEndTime(int *min,int *hour,int *day,int *month,int *year,int *dayofweek) const;

    virtual void fromXML(xmlNodePtr parent) throw(FWException);

    DECLARE_FWOBJECT_SUBTYPE(Interval);

    virtual FWReference* createRef();

    bool isAny();
};

}

#endif
